@@ -285,8 +285,12 @@ pub async fn next_message(
         }
 
         if peak[0] == magic_number {
+            //peak[1] Command
+            //peak[2-3] == length
+            let mut length_buf = Buffer::from(peak[2..4].to_vec());
+            let length = length_buf.read_u16().unwrap();
             //@handle ex message here.
-            let mut buffer = Buffer::from(peak);
+            let mut buffer = Buffer::from(&peak[0..length as usize + 1]);
             //@todo I think we need a consume here... But we need to be very careful about this
             //placement.
             stream.consume_unpin(buffer.len());
